import { OnDestroy, OnInit } from '@angular/core';
import { FilterToolbarService } from './filter-toolbar.service';
import { IIconInput } from '../shared/interfaces/icon-input.interface';
import { InboxState } from '../inbox/state/inbox.state';
import { MainFacadeSetterService } from '../inbox/services/main-facade-setter.service';
import { FilterStateService } from '../simple-filter-selection/state/filter.state';
import * as i0 from "@angular/core";
/**
 * FilterToolbar is used to display the filter toolbar in the inbox toolbar.
 *
 * ```html
 * <talenra-filter-toolbar
 *   [scrollBarShadow]="headerHidden()"
 *   [searchedAndFilteredDataItems]="filteredDataItems"
 * ></talenra-filter-toolbar>
 * ```
 */
export declare class FilterToolbarComponent implements OnInit, OnDestroy {
    /**
     * List of given IconFilters.
     */
    iconFilters: import("@angular/core").ModelSignal<IIconInput[]>;
    /**
     * The active preset name.
     * Used to check if the current preset is the same as the new preset.
     * If not, the filters and buffer are reset.
     */
    currentPresetName?: [string, string];
    /**
     * The used service.
     */
    filterToolbarService: FilterToolbarService;
    inboxState: InboxState;
    filterState: FilterStateService;
    mainFacadeSetterService: MainFacadeSetterService;
    /**
     * Subscriptions for the filter toolbar component.
     * @internal
     */
    private initialSubscriptions;
    /**
     * Initializes the filter toolbar component.
     * @internal
     */
    ngOnInit(): void;
    /**
     * Unsubscribe from all subscriptions.
     * @internal
     */
    ngOnDestroy(): void;
    /**
     * Function to handle the preset groups for the filter toolbar.
     * @param groupName The name of the group.
     * @param presetName The name of the preset.
     */
    handlePresetGroupsForFilterToolbar(groupName: string, presetName: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterToolbarComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<FilterToolbarComponent, "talenra-filter-toolbar", never, { "iconFilters": { "alias": "iconFilters"; "required": false; "isSignal": true; }; }, { "iconFilters": "iconFiltersChange"; }, never, never, true, never>;
}
