import { BehaviorSubject } from 'rxjs';
import { IQueryBuilderQuery, IQueryBuilderRule } from '@talenra/ngx-base/query-builder';
import { ISelectionFilterValue } from '../shared/interfaces/filter-attribute.interface';
import { IIconInput } from '../shared/interfaces/icon-input.interface';
import { IPreset } from '../shared/interfaces/preset.interface';
import * as i0 from "@angular/core";
/**
 * FilterToolbarService is used to share data between the filter toolbar and other components in the library.
 * The calculation of each filter is also done here.
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { FilterToolbarService } from '@talenra/ngx-inbox';
 * ```
 */
export declare class FilterToolbarService {
    /**
     * The filtered and sorted data items.
     * @internal
     */
    readonly filteredSortedDataItems$: BehaviorSubject<any[]>;
    /**
     * The original list of data items inputted by the consuming application.
     * @internal
     */
    readonly originalDataItems$: BehaviorSubject<any[]>;
    /**
     * Value for the active expert filter. If true, the expert filter is active.
     * Tag should be displayed and the expert filter should be shown.
     */
    activeExpertFilter$: BehaviorSubject<boolean>;
    /**
     * Map with all identifiers and the possible selections for the filter.
     */
    identifierWithPossibleSelection?: Map<string, ISelectionFilterValue[]>;
    /**
     * Sets the selectedDataItems subject.
     * @param key The value of the selected data items.
     * @internal
     */
    setFilteredSortedDataItems(key: any[]): void;
    /**
     * Sets the dataItemsSubject subject.
     * @param key The value of the unchanged list of data items.
     * @internal
     */
    setOriginalDataItems(key: any[]): void;
    /**
     * Gets the combined icon filter key.
     * @param iconInput The icon input to construct the key.
     */
    getIconFilterCombinedKey(iconInput: IIconInput): string;
    /**
     * Compares the rule objects between two values.
     * @param a First element to compare.
     * @param b Second element to compare.
     */
    compareQueryObjects(a: IQueryBuilderQuery | IQueryBuilderRule, b: IQueryBuilderQuery | IQueryBuilderRule): boolean;
    /**
     * Create new query object with the values.
     * @param query The query object to be created.
     */
    createQueryObject(query: IQueryBuilderQuery): IQueryBuilderQuery;
    /**
     * Create new rule object with the values.
     * @param rule The rule object to be created.
     */
    createRuleObject(rule: IQueryBuilderRule): IQueryBuilderRule;
    /**
     * Decide whether to create a rule or a query object.
     * @param ruleOrQuery The rule or query object to be created.
     */
    decideRuleOrQuery(ruleOrQuery: IQueryBuilderRule | IQueryBuilderQuery): IQueryBuilderRule | IQueryBuilderQuery;
    /**
     * Function to check if the filter and sort values have changed compared to the values in the preset.
     * @param presetGroups The preset groups.
     * @param searchedPresetName The searched preset name.
     */
    findPresetFromPresetsViaName(presetGroups: IPreset[], searchedPresetName: string[]): {
        foundValue: IPreset;
        parentName: string;
    } | undefined;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterToolbarService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FilterToolbarService>;
}
