import { BehaviorSubject } from 'rxjs';
import * as i0 from "@angular/core";
/**
 * Provides control and state of the publicly available subjects of the inbox detail view.
 *
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { InboxDetailViewService } from '@talenra/ngx-inbox';
 * ```
 */
export declare class InboxDetailViewService {
    /**
     * Provides whether the inbox detail view side panel is expanded. Note that the state
     * (collapsed or expanded) is kept even if the current layout does not involve
     * the inbox detail view side panel.
     */
    readonly detailViewExpanded$: BehaviorSubject<boolean>;
    /**
     * Provides the selectedItem's state (current item).
     */
    readonly selectedDetailViewTab$: BehaviorSubject<string>;
    /**
     * Provides the state whether the inbox note box is expanded.
     */
    readonly noteBoxExpanded$: BehaviorSubject<boolean>;
    /**
     * Collapses or expands the inbox detail view.
     *
     * @param isExpanded Whether the inbox detail view is expanded or not.
     */
    setDetailViewExpanded(isExpanded: boolean): void;
    /**
     * Updates the current selected item.
     *
     * @param key The key of the selected item (has to be a string from '1','2', '3' ... to the last tab).
     */
    setSelectedDetailViewTab(key: string): void;
    /**
     * Collapses or expands the inbox note box.
     *
     * @param isExpanded Whether the note box is expanded or not.
     */
    setNoteBoxExpanded(isExpanded: boolean): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InboxDetailViewService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<InboxDetailViewService>;
}
