import { BehaviorSubject } from 'rxjs';
import { CheckboxState } from '../shared/types/checkbox.types';
import * as i0 from "@angular/core";
/**
 * Provides control and state of the publicly available subjects of the inbox toolbar.
 *
 * ## Import Information:
 *
 * 1. Not all attributes are changeable. Or should be changed (consult the api documentation).
 *
 * ```typescript
 * import { InboxToolbarService } from '@talenra/ngx-inbox';
 * ```
 */
export declare class InboxToolbarService {
    /**
     * Number of data items which are currently selected.
     * Used to display the number of selected items in the toolbar as badge for the checkbox.
     * The value overwrites the default badge value.
     *
     * If default badge value should be used set the value to -1.
     * The value is set to 0 if no items are selected.
     * If the value is greater than 0 the badge is displayed with the value.
     * If the value is greater than 1 the ellipsis and arrow buttons are enabled.
     * If the value is greater than 99 the badge will display the value 99+.
     */
    readonly selectedItemsCount$: BehaviorSubject<number>;
    /**
     * Determines whether configuration panel is expanded.
     * @internal
     */
    readonly configurationPanelExpanded$: BehaviorSubject<boolean>;
    /**
     * The input is used to change the state of the toolbar checkbox. The input is an object of `CheckboxState`.
     * If inputted the checkbox functionality of the default data items list gets disabled and the checkboxes are set to the state of the input.
     * To activate the default checkboxes again, set the input to `undefined`.
     */
    readonly checkboxState$: BehaviorSubject<CheckboxState>;
    /**
     * Setter for the selected items count.
     * @param count The number of selected items.
     */
    setSelectedItemsCount(count: number): void;
    /**
     * Setter for configuration panel state.
     * @param state The state of the configuration panel.
     */
    setConfigurationPanelState(state: boolean): void;
    /**
     * Setter for the checkbox State.
     * @param state The state for the checkbox.
     */
    setCheckboxState(state: CheckboxState): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<InboxToolbarService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<InboxToolbarService>;
}
