import { BehaviorSubject } from 'rxjs';
import { MainFacadeSetterService } from './main-facade-setter.service';
import { InboxState } from '../state/inbox.state';
import { FilterStateService } from '../../simple-filter-selection/state/filter.state';
import { FilterToolbarService } from '../../filter-toolbar/filter-toolbar.service';
import * as i0 from "@angular/core";
/**
 * The service to check if the values of the filter and sort are changed in comparison to the default values of the preset.
 * @ignore
 */
export declare class ChangedPresetValuesService {
    /**
     * The state of the inbox.
     */
    inboxState: InboxState;
    /**
     * The state of the inbox.
     */
    filterState: FilterStateService;
    /**
     * The state of the inbox.
     */
    filterToolbarService: FilterToolbarService;
    /**
     * The state of the main facade setter.
     */
    mainFacadeSetterService: MainFacadeSetterService;
    /**
     * The subject to check if the attributes are changed in comparison to the active preset.
     */
    readonly attributesMainChangedSubject$: BehaviorSubject<{
        identifier: string;
        changed: boolean;
    }>;
    /**
     * The subject to check if the attributes details are changed in comparison to the active preset.
     */
    readonly attributesDetailChangedSubject$: BehaviorSubject<{
        identifier: string;
        changed: boolean;
    }>;
    /**
     * The subject to check if the number of main attributes chosen by the user is changed in comparison to the active preset.
     */
    readonly numberMainAttributesChosenByUserChangedSubject$: BehaviorSubject<{
        identifier: string;
        changed: boolean;
    }>;
    /**
     * The subject to check if the sort is changed in comparison to the active preset.
     */
    readonly sortChangedSubject$: BehaviorSubject<{
        identifier: string;
        changed: boolean;
    }>;
    /**
     * The subject to check if the icon filter is changed in comparison to the active preset.
     */
    readonly iconFilterChangedSubject$: BehaviorSubject<{
        identifier: string;
        changed: boolean;
    }>;
    /**
     * The subject to check if the filter is changed in comparison to the active preset.
     */
    readonly filterChangedSubject$: BehaviorSubject<{
        identifier: string;
        changed: boolean;
    }>;
    /**
     * Value if there are changes of the inbox from the default values of the preset.
     */
    readonly inboxStateChangedSubject$: BehaviorSubject<boolean>;
    /**
     * Set the attributes changed subject.
     * @param key The key to set the attributes changed subject.
     */
    setAttributesMainChangedSubject(key: {
        identifier: string;
        changed: boolean;
    }): void;
    /**
     * Set the attributes details changed subject.
     * @param key The key to set the attributes details changed subject.
     */
    setAttributesDetailChangedSubject(key: {
        identifier: string;
        changed: boolean;
    }): void;
    /**
     * Set the number of main attributes chosen by the user changed subject.
     * @param key The key to set the number of main attributes chosen by the user changed subject.
     */
    setNumberMainAttributesChosenByUserChangedSubject(key: {
        identifier: string;
        changed: boolean;
    }): void;
    /**
     * Set the sort changed subject.
     * @param key The key to set the sort changed subject.
     */
    setSortChangedSubject(key: {
        identifier: string;
        changed: boolean;
    }): void;
    /**
     * Set the icon filter changed subject.
     * @param key The key to set the icon filter changed subject.
     */
    setIconFilterChangedSubject(key: {
        identifier: string;
        changed: boolean;
    }): void;
    /**
     * Set the filter changed subject.
     * @param key The key to set the filter changed subject.
     */
    setFilterChangedSubject(key: {
        identifier: string;
        changed: boolean;
    }): void;
    /**
     * Set the inbox state changed subject.
     * @param key The key to set the filter and sort changed subject.
     */
    setInboxStateChangedSubject$(key: boolean): void;
    /**
     * Checks if icon filter are changed in comparison to the active preset.
     */
    checkIconFilterValuesChangedComparedToValuesInPreset(): void;
    /**
     * Checks if attributes are changed in comparison to the active preset.
     */
    checkAttributesChangedComparedToValuesInPreset(): void;
    /**
     * Function to check if the filter values have changed compared to the values in the preset.
     * If the values have changed, the attributeSortOrFilterUsedSubject$ is set to true.
     */
    checkFilterValuesChangedComparedToValuesInPreset(): void;
    /**
     * Function to check if the sort values have changed compared to the values in the preset.
     */
    checkSortValuesChangedComparedToValuesInPreset(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<ChangedPresetValuesService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<ChangedPresetValuesService>;
}
