import { BehaviorSubject } from 'rxjs';
import { IPreset } from '../../shared/interfaces/preset.interface';
import { TPresetOperations } from '../../shared/interfaces/preset-action.interface';
import * as i0 from "@angular/core";
/**
 * Service to update the presets and check if the inbox has changed.
 */
export declare class UpdatePresetsService {
    /**
     * Containing the current preset action which is to emit to the consuming application.
     */
    currentPresetAction$: BehaviorSubject<{
        operation: TPresetOperations;
        groupName: string;
        presetName?: string;
        newPresetName?: string;
    }>;
    /**
     * The presets group that are to be emitted to the consuming application.
     */
    modifiedPresets$: BehaviorSubject<IPreset[]>;
    /**
     * The preset that is to be renamed.
     */
    currentRenamedPreset$: BehaviorSubject<{
        groupName: string;
        presetName: string;
        newPresetName: string;
    }>;
    /**
     * The name of the new preset is saved here.
     * [groupName, presetName]
     */
    newPresetName$: BehaviorSubject<string[]>;
    /**
     * The filter toolbar service.
     */
    private filterToolbarService;
    /**
     * Injected filter state.
     */
    private filterState;
    /**
     * The main facade setter service.
     */
    private mainFacadeSetterService;
    /**
     * The inbox state.
     */
    private inboxState;
    /**
     * Injected presets service.
     */
    private presetsService;
    /**
     * Set the current preset action.
     * @param presetAction
     */
    private setCurrentPresetAction;
    /**
     * Set the modified presets.
     * @param presets The presets.
     */
    private setModifiedPresets;
    /**
     * Set the current renamed preset, by the preset textarea field.
     * @param renamedPreset The renamed preset. [groupName, presetName, newPresetName]
     */
    setCurrentRenamedPreset(renamedPreset: {
        groupName: string;
        presetName: string;
        newPresetName: string;
    }): void;
    /**
     * Set the new preset name from the different fields.
     * @param newPresetName The new preset name. [groupName, presetName]
     */
    setNewPresetName(newPresetName: string[]): void;
    /**
     * Method to change visibility of preset in preset groups.
     * @param presetName The [groupName, presetName]
     * @param visibility boolean
     */
    private changeVisibilityOfPresetInPresets;
    /**
     * Method to delete a preset in preset groups.
     * @param presetNames The [groupName, presetName]
     */
    private deletePresetInPresets;
    /**
     * Change the name of a preset.
     * @param presetNames The groupName, presetName, newPresetName.
     */
    private renamePresetInPresets;
    /**
     * Method to change the position of presets in preset groups.
     * @param groupName The group name.
     * @param presetName The preset name.
     * @param upOrDown Boolean to indicate if the preset should be moved up or down.
     */
    private changePositionOfPresetInPresets;
    /**
     * Method to swap presets in preset groups.
     * @param groupName The group name.
     * @param presetNameOne The first preset name.
     * @param presetNameTwo The second preset name.
     */
    private swapPresetInPresets;
    /**
     * Method to change the position of presets in preset groups.
     * @param event The position change event. [groupName, presetName, upOrDown]
     */
    private dragDropPresetInPresets;
    /**
     * Method to set the new/overwrite preset groups for the preset.
     * @param command The command to execute, create or overwrite.
     */
    private setAllNewSettingsForPreset;
    /**
     * Set the main attributes to the new preset.
     */
    private setMainAttributesToNewPreset;
    /**
     * Set the details attributes to the new preset.
     */
    private setDetailsAttributesToNewPreset;
    /**
     * Set the sort filter to the new preset.
     */
    private setSortFilterToNewPreset;
    /**
     * Set the sort filter to the new preset.
     */
    private setIconFilterToNewPreset;
    /**
     * Set the visibility to the new preset.
     */
    private setVisibilityToNewPreset;
    /**
     * Set the number of main attributes to the new preset.
     */
    private setNumberMainAttributesChosenByUserToPreset;
    /**
     * Set the filter to the new preset.
     */
    private setFilterToNewPreset;
    /**
     * Handles the changes in the presets.
     * @param action The action to execute.
     */
    handleChangesOfPreset(action: string): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<UpdatePresetsService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<UpdatePresetsService>;
}
