import { ValidatorFn } from '@angular/forms';
import { INoteBoxItem } from '../interfaces/note-box-item.interface';
import { IIconInput } from '../interfaces/icon-input.interface';
/**
 * DataItemClass necessary to check:
 * - if a string value is contained in all the string attributes of a data item
 * - if a data item is a duplicate
 * - to create the notes from a data item
 * - to get a property from a data item
 * - to format a date to MM/DD/YYYY
 * - to check if a date is invalid
 *
 */
export declare class DataItemsClass {
    /**
     * The charRangeAlphabet is the alphabet that is used for the char range filter.
     * @internal
     */
    static readonly charRangeAlphabet = "A\u00C0\u00C1\u00C2\u00C3\u00C4\u00C5\u00C6BC\u00C7D\u00D0E\u00C8\u00C9\u00CA\u00CBFGHI\u00CC\u00CD\u00CE\u00CFJKLMN\u00D1O\u00D2\u00D3\u00D4\u00D5\u00D6PQRSTU\u00D9\u00DA\u00DB\u00DCVWXY\u00DD\u00FFZ0123456789!\"#$%&'()*+,-./:;<=>?@[\\]^_`{|}~\u20AC\u201A\u0192\u201E\u2026\u2020\u2021\u02C6\u2030\u0160\u2039\u0152\u017D\u2018\u2019\u201C\u201D\u2022\u2013\u2014\u02DC\u2122\u0161\u203A\u0153\u017E\u0178\u00A1\u00A2\u00A3\u00A4\u00A5\u00A6\u00A7\u00A8\u00A9\u00AA\u00AB\u00AC\u00AE\u00AF\u00B0\u00B1\u00B2\u00B3\u00B4\u00B5\u00B6\u00B7\u00B8\u00B9\u00BA\u00BB\u00BC\u00BD\u00BE\u00BF\u00D7\u00D8\u00DE\u00DF\u00F0\u00F7\u00FE";
    /**
     * This method is used to create the notes from a data item.
     * @param dataItem The data item to create the notes from.
     * @param iconAttributes The icon attributes to create the notes from.
     */
    createNotesFromDataItem(dataItem: any, iconAttributes: IIconInput[]): INoteBoxItem[];
    /**
     * This method is used to get a property from a data item.
     * @param specificDataItem The data item to get the property from.
     * @param label The label of the property to get.
     */
    getElemFromDataItemDisplayed(specificDataItem: any, label: string): any;
    /**
     * Auxiliary method to get the value of a property from a data item.
     * Returns null, Number, Date or string values.
     * @param specificDataItem The data item to get the property from.
     * @param label The label of the property to get.
     */
    getElemFromDataItemValue(specificDataItem: any, label: string): any;
    /**
     * This method is used to set a property from a data item.
     * @param specificDataItem The data item to set the property from.
     * @param label The label of the property to set.
     * @param value The value to set.
     */
    setElemFromDataItemValue(specificDataItem: any, label: string, value: any): void;
    /**
     * This method is used to get a property from a data item.
     * @param object The object to get the property from.
     * @param keys The keys of the property to get.
     */
    getProp(object: any, keys: string[]): any;
    /**
     * This method is used to set a property from a data item.
     * @param object
     * @param keys
     * @param value
     */
    setProp(object: any, keys: string[], value: any): void;
    /**
     * Format a date to MM/DD/YYYY from DD.MM.YYYY.
     * @param date The date to format.
     */
    formatDate(date: any): any;
    /**
     * Check if a date is invalid.
     * @param dateString The date to check.
     */
    isDateInvalid(dateString: string): boolean;
    static startBeforeEnd(startId: string, endId: string, allowSame?: boolean): ValidatorFn;
    /**
     * Sorts the string values.
     * Returns -1 if a is smaller than b.
     * @param a String to compare.
     * @param b String to compare.
     * @internal
     */
    static sortString(a: string, b: string): 1 | -1;
    /**
     * Replaces specific char in a string at a specific index.
     * @param str String to replace char in.
     * @param index Index where to replace in str.
     * @param replacement Replacement char.
     * @internal
     */
    static replaceCharAt(str: string, index: number, replacement: string): string;
}
