import { ISortAttributesInput } from './sort-attributes-input.interface';
import { IIconFiltersInput } from './icon-filters-input.interface';
import { IAttributeItem } from './attribute-item.interface';
import { IFilterAttribute } from './filter-attribute.interface';
import { IQueryBuilderQuery } from '@talenra/ngx-base/query-builder';
/**
 * IFilterSortSearch is used to define what kind of filters, sort and searched text are used in the inbox.
 *
 * @example
 * import { IFilterSortSearch } from '@talenra/ngx-inbox';
 *
 * filterSortSearch: IFilterSortSearch = {
 *   searchText: 'searched text',
 *   sortAttributes: [{identifier: 'caseId', sort: 'asc'}],
 *   filterAttributes: [{ identifier: 'animal.mammal', value: [{ key: 'landAnimalMonkey', label: 'Monkey' }, { key: 'waterAnimalWhale', label: 'Whale' }] },  { identifier: 'animal.mammal', value: { start: 'AR', end: 'JAB' } }],
 *   iconAttributes: [{ icon: "error", identifier: "icon_error_insuree.partnerFlags" }],
 *   };
 */
export interface IFilterSortSearch {
    /**
     * The selected main attributes.
     */
    selectedMainAttributes: IAttributeItem[];
    /**
     * The selected detail attributes.
     */
    selectedDetailAttributes: IAttributeItem[];
    /**
     * Searched text in the search bar.
     **/
    searchText: string;
    /**
     * SortAttributes is used to define which attributes are used to sort the items in the inbox.
     */
    sortAttributes: ISortAttributesInput[];
    /**
     * FilterAttributes is used to define which attributes are used to filter the items in the inbox.
     */
    filterAttributes: IQueryBuilderQuery;
    /**
     * SimpleFilterAttributes is used to define which attributes are used to filter the items in the inbox.
     * #Important: only temporary, will be removed after rc phase
     */
    simpleFilterAttributes?: IFilterAttribute[];
    /**
     * Number of main attributes chosen by user.
     */
    numberMainAttributesChosenByUser: number;
    /**
     * IconAttributes is used to define which icon filters are active in the inbox.
     */
    iconAttributes: IIconFiltersInput[];
}
