/**
 * Configuration model for the inbox component.
 */
export interface IInboxConfiguration {
    /**
     * Defines the maximum number of attributes to be displayed in the list view.
     */
    maxAttributesList?: number;
    /**
     * Defines the maximum number of attributes to be displayed in the detail view.
     */
    maxAttributesDetailView?: number;
    /**
     * Disables the toolbar.
     */
    disableToolbar?: boolean;
    /**
     * Disables the search in the toolbar.
     */
    disableSearchToolbar?: boolean;
    /**
     * Disables the refresh button in the toolbar.
     */
    disableRefreshToolbar?: boolean;
    /**
     * Disables the detail view toggle button in the toolbar (disables keyboard shortcut).
     */
    disableDetailViewToggleToolbar?: boolean;
    /**
     * Disables the detail view toggle button in the toolbar (disables keyboard shortcut).
     */
    disableCompressedDataListItemsToolbar?: boolean;
    /**
     * Disables the attributes settings button in the toolbar and the attributes settings component (disables keyboard shortcut).
     */
    disableAttributeSettingsToolbar?: boolean;
    /**
     * Disables the preset menu in the toolbar.
     */
    disablePresetMenuToolbar?: boolean;
    /**
     * Disables the CSV export button in the toolbar.
     */
    disableCSVExportToolbar?: boolean;
    /**
     * Disables the checkbox, further Actions Button and continue Button in toolbar.
     */
    disableBulkInteractionsToolbar?: boolean;
    /**
     * Disables the further Actions Button in toolbar.
     */
    disableCheckboxInteractionsToolbar?: boolean;
    /**
     * Disables the further Actions Button in toolbar.
     */
    disableBulkFurtherInteractionsToolbar?: boolean;
    /**
     * Disables the continue Button in toolbar.
     */
    disableBulkContinueButtonToolbar?: boolean;
    /**
     * The maximum number which is displayed in the badge counter in the toolbar. If the number of selected items is higher, the badge counter shows the maximum number and a plus sign.
     */
    maxBadgeCounterToolbar?: number;
    /**
     * Disables the filter toolbar.
     */
    disableFilterToolbar?: boolean;
    /**
     * Disables the filter selection in the filter toolbar.
     */
    disableFilterSelection?: boolean;
    /**
     * Disables the sort selection in the filter toolbar.
     */
    disableSortSelection?: boolean;
    /**
     * Disables the quick filters in the filter toolbar.
     */
    disableQuickFilters?: boolean;
    /**
     * Disables the inbox sorting.
     */
    disableInboxSorting?: boolean;
    /**
     * Disables the data items list.
     */
    disableDataItemsList?: boolean;
    /**
     * Disables the notes in the data items list.
     */
    disableNotesDataItemsList?: boolean;
    /**
     * Enables the labels before the value in the data items list.
     */
    showAttributeLabelsDataItemsList?: boolean;
    /**
     * Disables the checkbox, further Actions Button and continue Button.
     */
    disableInteractionsDataItemsList?: boolean;
    /**
     * Disables the checkbox in the data items list.
     */
    disableCheckboxDataItemsList?: boolean;
    /**
     * Disables the further Actions Button in the data items list.
     */
    disableFurtherInteractionsDataItemsList?: boolean;
    /**
     * Disables the continue Button in toolbar.
     */
    disableContinueButtonDataItemsList?: boolean;
    /**
     * Disables the detail view.
     */
    disableDetailView?: boolean;
    /**
     * Disables the note box in the detail view.
     */
    disableNoteBox?: boolean;
    /**
     * Enables the custom note box in the detail view.
     */
    useCustomNoteBox?: boolean;
    /**
     * Sets that the first tab of detail view is disabled.
     */
    disableDetailViewMainTab?: boolean;
    /**
     * Sets the title in the first tab of detail view.
     */
    detailViewMainTabTitle?: string;
    /**
     * Sets the icon for the first tab of detail view.
     * NOTE: Not changeable on the fly, only on init.
     */
    detailViewMainTabIcon?: string;
    /**
     * Disables the keyboard input of the inbox.
     */
    disableKeyBoardInputInbox?: boolean;
    /**
     * Disables the user chosen number of the main attributes.
     */
    disableFlexibleMainAttributes?: boolean;
    /**
     * Sets the title of the attribute settings component.
     */
    attributeSettingsTitle?: string;
}
