/**
 * INoteBoxItem is used to define the structure of the note box items.
 *
 * @example
 * import { INoteBoxItem } from '@talenra/ngx-inbox';
 *
 * noteBoxItems: INoteBoxItem =
 *    {
 *    identifier: 'casePriority',
 *    icon: 'info',
 *    iconColor: 'status-red',
 *    content: 'This is a note box item.',
 *    };
 */
export interface INoteBoxItem {
    /**
     * The identifier is used to identify the note box item.
     */
    identifier: string;
    /**
     * The icon is limited by the talenra-icon library (https://gitlab.svanet.ch/talenra/talenra-workspace).
     */
    icon: string;
    /**
     * The color of the icon if it is active.
     */
    activeIconColor: 'status-red' | 'status-green' | 'status-orange' | 'status-violet' | 'primary' | 'black';
    /**
     * The displayed note of the note box item.
     */
    note: string;
}
