/**
 * Interface for pairing attributes, sets to attribute in a pair to each other.
 *
 * @example
 * import { IPairingAttributes } from '@talenra/ngx-inbox';
 *
 * pairingAttributes: IPairingAttributes = {
 *      identifier: 'pairingAttributes',
 *      label: 'Pairing Attribute',
 *      firstAttribute: 'firstAttribute',
 *      secondAttribute: 'secondAttribute',
 *      commaSeparation: true,
 *      };
 */
export interface IPairingAttributes {
    /**
     * Identifier to set the pairing attribute in the `dataItems`.
     */
    identifier: string;
    /**
     * The label is used to define the displayed label of the pairing attribute.
     */
    label: string;
    /**
     * FirstAttribute is used to define the first attribute of the pairing attribute.
     * Has to correspond with an identifier given in the `attributes`.
     */
    firstAttribute: string;
    /**
     * SecondAttribute is used to define the second attribute of the pairing attribute..
     * Has to correspond with an identifier given in the `attributes`.
     */
    secondAttribute: string;
    /**
     * CommaSeparation is used to define if a comma is displayed in between the two attributes.
     * If commaSeparation is true, a comma is displayed in between the two attributes.
     * If commaSeparation is false, no comma is displayed in between the two attributes.
     */
    commaSeparation: boolean;
}
