/**
 * Configuration of the buttons in the dialog.
 * @see {@link IPresetConfirmationConfig}
 */
export interface IPresetConfirmationButtonConfig {
    /** The label of the button. */
    label: string;
    /** The action to be executed when the button is clicked. */
    action: () => void;
}
/**
 * Configuration of the confirmation dialog.
 *
 * ```typescript
 * private config: IConfirmationConfig = {
 *   currentPresetName: 'Current Preset Name',
 *   newPresetName: 'New Preset Name',
 *   confirm: {
 *     label: 'Button Label',
 *     action: () => {
 *       console.log('Confirm clicked');
 *     },
 *   },
 * };
 * ```
 *
 * @see {@link PresetConfirmationComponent}
 */
export interface IPresetConfirmationConfig {
    /** The main text to be displayed in the dialog. */
    currentPresetName?: string;
    /** The additional information to be displayed in the dialog. */
    newPresetName?: string;
    /** Whether overwrite of a preset is possible.  */
    overWrite?: boolean;
    /** The configuration for the confirm button. */
    cancel: IPresetConfirmationButtonConfig;
    /** The configuration for the confirm button. */
    confirm: IPresetConfirmationButtonConfig;
}
