import { DestroyRef, OnChanges, SimpleChanges } from '@angular/core';
import { FormGroup } from '@angular/forms';
import { SelectChange } from '@talenra/ngx-base/select';
import { FilterToolbarService } from '../filter-toolbar/filter-toolbar.service';
import { IAttributeItem } from '../shared/interfaces/attribute-item.interface';
import { IFilterAttribute } from '../shared/interfaces/filter-attribute.interface';
import { ISelectedFilterAttribute } from '../shared/interfaces/selected-filter-attribute.interface';
import * as i0 from "@angular/core";
export declare class SimpleFilterSelectionComponent implements OnChanges {
    /**
     * The availableAttributes input is an array of AttributeItem that contains the available filters.
     */
    availableAttributes: import("@angular/core").InputSignal<IAttributeItem[]>;
    /**
     * The filterSelection input is an array of strings that contains the selected filters.
     */
    filterSelections: import("@angular/core").InputSignal<IFilterAttribute[]>;
    /**
     * The selectedFilters output is an array of strings that contains the selected filters.
     */
    filterSelectionsChange: import("@angular/core").OutputEmitterRef<IFilterAttribute[]>;
    /**
     * The availableAttributes output is an array of AttributeItem that contains the available filters.
     */
    copyAvailableAttributes: import("@angular/core").Signal<IAttributeItem[]>;
    /**
     * The selectedAttributes input is an array of AttributeItem that contains the selected filters.
     */
    selectedAttributes: ISelectedFilterAttribute[];
    /**
     * The filters array contains the selected filters.
     */
    filters: IFilterAttribute[];
    /**
     * The inbox service and references.
     */
    filterToolbarService: FilterToolbarService;
    destroyRef: DestroyRef;
    /**
     * The selected values.
     */
    selectionForm: FormGroup;
    /**
     * @internal
     */
    ngOnChanges(changes: SimpleChanges): void;
    /**
     * Called when the user selects a filter.
     * @param selectChange The select change.
     */
    onAttributeSelectionAdd(selectChange: SelectChange): void;
    /**
     * Removes the filter from the selection.
     * @param mouseEvent The mouse event.
     * @param selectedAttribute The selected attribute.
     * @param filterIndex The filter index.
     */
    deleteFilterAttribute(mouseEvent: MouseEvent, selectedAttribute: ISelectedFilterAttribute, filterIndex: number): void;
    /**
     * Called when the user selects a filter.
     * @param filterIndex The filter index.
     * @param filterAttribute The filter attribute.
     **/
    onFilterSelection(filterIndex: number, filterAttribute: ISelectedFilterAttribute): void;
    /**
     * Changes the value of the operator.
     * @param selectedAttributes The selected attributes.
     */
    changeOperator(selectedAttributes: ISelectedFilterAttribute): void;
    /**
     * Called when the user changes a filter attribute.
     * @param selectChange The select change.
     * @param index The index.
     */
    onAttributeSelectionChange(selectChange: SelectChange, index: number): void;
    /**
     * Called when the user clicks the x button in the filter attribute selection.
     * @param value The value of the attribute selector.
     * @param index The index.
     */
    onAttributeSelectionModelChange(value: SelectChange, index: number): void;
    /**
     * Resets the copy available attributes.
     */
    private resetCopyAvailableAttributes;
    /**
     * Auxiliar function to set the filters.
     */
    private setFilters;
    static ɵfac: i0.ɵɵFactoryDeclaration<SimpleFilterSelectionComponent, never>;
    static ɵcmp: i0.ɵɵComponentDeclaration<SimpleFilterSelectionComponent, "talenra-simple-filter-selection", never, { "availableAttributes": { "alias": "availableAttributes"; "required": false; "isSignal": true; }; "filterSelections": { "alias": "filterSelections"; "required": false; "isSignal": true; }; }, { "filterSelectionsChange": "filterSelectionsChange"; }, never, never, true, never>;
}
