import { BehaviorSubject } from 'rxjs';
import { IQueryBuilderQuery } from '@talenra/ngx-base/query-builder';
import { IIconInput } from '../../shared/interfaces/icon-input.interface';
import { ISortAttributesInput } from '../../shared/interfaces/sort-attributes-input.interface';
import * as i0 from "@angular/core";
export declare class FilterStateService {
    /**
     * The simple filter subject.
     */
    readonly simpleFilterSubject$: BehaviorSubject<IQueryBuilderQuery>;
    /**
     * The sort subject.
     */
    readonly sortSubject$: BehaviorSubject<ISortAttributesInput[]>;
    /**
     * The icon filter subject.
     */
    readonly iconFilterSubject$: BehaviorSubject<IIconInput[]>;
    /**
     * The attributes/filter/sort/icon-filter state in comparison to emitted state signal.
     * If true, the attributes/filter/sort/icon-filter state has changed in comparison to the emitted state.
     * If false, the attributes/filter/sort/icon-filter state has not changed in comparison to the emitted state.
     */
    readonly inboxStateInComparisonToEmittedState: import("@angular/core").WritableSignal<boolean>;
    /**
     * Contains the signal if any range filter has a false order.
     * Contains the key of each range filter with a false order.
     */
    readonly falseOrderRangeFilter: BehaviorSubject<string[]>;
    /**
     * Contains the signal if the expert filter mode is active.
     */
    readonly expertFilterMode$: BehaviorSubject<boolean>;
    /**
     * Sets the simple filter subject.
     * @param key The simple filter subject.
     */
    setSimpleFilterSubject(key: IQueryBuilderQuery): void;
    /**
     * Sets the sort subject.
     * @param key The sort subject.
     */
    setSortSubject(key: ISortAttributesInput[]): void;
    /**
     * Sets the icon filter subject.
     * @param key The icon filter subject.
     */
    setIconFilterSubject(key: IIconInput[]): void;
    /**
     * Sets the attributes/filter/sort/icon-filter in comparison to emitted state.
     * @param key The attributes/filter/sort/icon-filter in comparison to emitted state.
     */
    setInboxStateInComparisonToEmittedState(key: boolean): void;
    /**
     * Sets the expert filter mode.
     * @param key The expert filter mode.
     */
    setExpertFilterMode(key: boolean): void;
    /**
     * Adds a false order range filter.
     * @param key The key of the range filter to add.
     */
    addFalseOrderRangeFilter(key: string): void;
    /**
     * Removes a false order range filter.
     * @param key The key of the range filter to remove.
     */
    removeFalseOrderRangeFilter(key: string): void;
    /**
     * Checks if a false order range filter is contained.
     * @param key The key of the range filter to check.
     */
    containsFalseOrderRangeFilter(key: string): boolean;
    /**
     * Resets the simple filter selection.
     */
    resetSimpleFilterSelection(): void;
    /**
     * Resets the sort selection.
     */
    resetSortSelection(): void;
    static ɵfac: i0.ɵɵFactoryDeclaration<FilterStateService, never>;
    static ɵprov: i0.ɵɵInjectableDeclaration<FilterStateService>;
}
